@@ -1,3 +1,3 @@
-from core import (DojoInput, DojoTextBox, DojoValidationTextBox, DojoNumberTextBox, DojoPasswordBox,
+from .core import (DojoInput, DojoTextBox, DojoValidationTextBox, DojoNumberTextBox, DojoPasswordBox,
                   DojoTextArea, DojoSimpleTextArea, DojoDateTextBox, DojoTimeTextBox, DojoNumberSpinner,
                   DojoFilteringSelect, DojoMultiSelect, DojoCheckBox)
